@@ -1,6 +1,6 @@
 Components.utils.import("resource://gre/modules/Services.jsm");
-Components.utils.import("resource://app/modules/l10nHelper.jsm");
-Components.utils.import("resource://app/modules/prompterHelper.jsm");
+Components.utils.import("resource://gre/modules/l10nHelper.jsm");
+Components.utils.import("resource://gre/modules/prompterHelper.jsm");
 
 function Startup()
 {
